==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/sr@latin.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Korak 1 nije uspeo. Izuzetak: %s",
    "Step 2 failed. Exception: %s" : "Korak 2 nije uspeo. Izuzetak: %s",
    "External storage" : "Spoljašnje skladište",
    "Personal" : "Lično",
    "System" : "Sistemsko",
    "Grant access" : "Dozvoli pristup",
    "Access granted" : "Pristup Dozvoljen",
    "All users. Type to select user or group." : "Svi korisnici. Kucajte da biste izabrali korisnika ili grupu.",
    "(group)" : "(grupa)",
    "Saved" : "Sačuvano",
    "App key" : "Ključ Aplikacije",
    "App secret" : "Tajna lozinka Aplikacije",
    "Client ID" : "Identifikator klijenta",
    "Client secret" : "Tajna lozinka klijenta",
    "Username" : "Korisničko ime",
    "Password" : "Lozinka",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Korpa",
    "Hostname" : "Ime računara",
    "Port" : "Port",
    "Region" : "Regija",
    "Enable SSL" : "Uključi SSL",
    "Enable Path Style" : "Omogući stil putanje",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Udaljeni poddirektorijum",
    "Secure https://" : "Sigurni https://",
    "Host" : "Računar",
    "Secure ftps://" : "Sigurni ftps://",
    "Local" : "Lokalno",
    "Location" : "Lokacija",
    "Root" : "Koren",
    "Share" : "Podeli",
    "SMB / CIFS using OC login" : "SMB / CIFS koji koristi OC prijavljivanje",
    "Username as share" : "Korisničko ime i deljeni direktorijum",
    "OpenStack Object Storage" : "OpenStack skladište objekata",
    "<b>Note:</b> " : "<b>Obratite pažnju:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Obratite pažnju</b> Podrška za cURL u PHP-u nije uključena ili instalirana. Montiranje %s nije moguće. Molimo Vas da se obratite Vašem sistem administratoru da je instalira.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Obratite pažnju:</b> FTP podrška u PHP-u nije uključena ili instalirana. Montiranje %s nije moguće. Molimo Vas da tražite od Vašeg sistem administratora da je instalira.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Obratite pažnju:</b> \"%s\" nije instaliran. Monitranje %s nije moguće. Molimo Vas da se obratite Vašem sistem administratoru da to instalira.",
    "Name" : "Ime",
    "Storage type" : "Tip skladišta",
    "Scope" : "Opseg",
    "External Storage" : "Spoljašnje skladište",
    "Folder name" : "Ime fascikle",
    "Configuration" : "Podešavanje",
    "Available for" : "Dostupno za",
    "Delete" : "Obriši",
    "Add storage" : "Dodaj skladište",
    "Enable User External Storage" : "Omogući korisničko spoljašnje skladište",
    "Allow users to mount the following external storage" : "Omogući korisnicima da namontiraju sledeće spoljašnje skladište"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/sr@latin.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Korak 1 nije uspeo. Izuzetak: %s",
    "Step 2 failed. Exception: %s" : "Korak 2 nije uspeo. Izuzetak: %s",
    "External storage" : "Spoljašnje skladište",
    "Personal" : "Lično",
    "System" : "Sistemsko",
    "Grant access" : "Dozvoli pristup",
    "Access granted" : "Pristup Dozvoljen",
    "All users. Type to select user or group." : "Svi korisnici. Kucajte da biste izabrali korisnika ili grupu.",
    "(group)" : "(grupa)",
    "Saved" : "Sačuvano",
    "Username" : "Korisničko ime",
    "Password" : "Lozinka",
    "Save" : "Sačuvaj",
    "App key" : "Ključ Aplikacije",
    "App secret" : "Tajna lozinka Aplikacije",
    "Client ID" : "Identifikator klijenta",
    "Client secret" : "Tajna lozinka klijenta",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Korpa",
    "Hostname" : "Ime računara",
    "Port" : "Port",
    "Region" : "Regija",
    "Enable SSL" : "Uključi SSL",
    "Enable Path Style" : "Omogući stil putanje",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Udaljeni poddirektorijum",
    "Secure https://" : "Sigurni https://",
    "Host" : "Računar",
    "Secure ftps://" : "Sigurni ftps://",
    "Local" : "Lokalno",
    "Location" : "Lokacija",
    "Root" : "Koren",
    "Share" : "Podeli",
    "SMB / CIFS using OC login" : "SMB / CIFS koji koristi OC prijavljivanje",
    "Username as share" : "Korisničko ime i deljeni direktorijum",
    "OpenStack Object Storage" : "OpenStack skladište objekata",
    "<b>Note:</b> " : "<b>Obratite pažnju:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Obratite pažnju</b> Podrška za cURL u PHP-u nije uključena ili instalirana. Montiranje %s nije moguće. Molimo Vas da se obratite Vašem sistem administratoru da je instalira.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Obratite pažnju:</b> FTP podrška u PHP-u nije uključena ili instalirana. Montiranje %s nije moguće. Molimo Vas da tražite od Vašeg sistem administratora da je instalira.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Obratite pažnju:</b> \"%s\" nije instaliran. Monitranje %s nije moguće. Molimo Vas da se obratite Vašem sistem administratoru da to instalira.",
    "Name" : "Ime",
    "Storage type" : "Tip skladišta",
    "Scope" : "Opseg",
    "External Storage" : "Spoljašnje skladište",
    "Folder name" : "Ime fascikle",
    "Configuration" : "Podešavanje",
    "Available for" : "Dostupno za",
    "Add storage" : "Dodaj skladište",
    "Delete" : "Obriši",
    "Allow users to mount the following external storage" : "Omogući korisnicima da namontiraju sledeće spoljašnje skladište",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Obratite pažnju:</b> FTP podrška u PHP-u nije uključena ili instalirana. Montiranje %s nije moguće. Molimo Vas da tražite od Vašeg sistem administratora da je instalira.",
    "SMB / CIFS using OC login" : "SMB / CIFS koji koristi OC prijavljivanje"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
